==> paycenter-client-3.4.24-p1-20230705.050717-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/alipay/AlipayActivityInfoResponse.java <==
package cn.com.duiba.paycenter.dto.payment.charge.alipay;

import java.io.Serializable;

public class AlipayActivityInfoResponse implements Serializable {

    private static final long serialVersionUID = -4350183925162469662L;

    private String activityId;
    private String activityName;
    private String activityStatus;
    private String sendCount;
    private String userInstructionList;
    private String sendBeginTime;
    private String sendEndTime;
    private String discountThresholdAmt;
    private String discountValue;
    private String couponAvailablePeriodType;
    private String couponAbsolutelyBeginTime;
    private String couponAbsolutelyEndTime;
    private String couponRelativeEndRoundingType;
    private String couponRelativeEndValue;
    private Integer bankCardType;
    private String cardBinList;

    public Integer getBankCardType() {
        return bankCardType;
    }

    public void setBankCardType(Integer bankCardType) {
        this.bankCardType = bankCardType;
    }

    public String getCardBinList() {
        return cardBinList;
    }

    public void setCardBinList(String cardBinList) {
        this.cardBinList = cardBinList;
    }

    public String getDiscountThresholdAmt() {
        return discountThresholdAmt;
    }

    public void setDiscountThresholdAmt(String discountThresholdAmt) {
        this.discountThresholdAmt = discountThresholdAmt;
    }

    public String getDiscountValue() {
        return discountValue;
    }

    public void setDiscountValue(String discountValue) {
        this.discountValue = discountValue;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityStatus() {
        return activityStatus;
    }

    public void setActivityStatus(String activityStatus) {
        this.activityStatus = activityStatus;
    }

    public String getSendCount() {
        return sendCount;
    }

    public void setSendCount(String sendCount) {
        this.sendCount = sendCount;
    }

    public String getUserInstructionList() {
        return userInstructionList;
    }

    public void setUserInstructionList(String userInstructionList) {
        this.userInstructionList = userInstructionList;
    }

    public String getSendBeginTime() {
        return sendBeginTime;
    }

    public void setSendBeginTime(String sendBeginTime) {
        this.sendBeginTime = sendBeginTime;
    }

    public String getSendEndTime() {
        return sendEndTime;
    }

    public void setSendEndTime(String sendEndTime) {
        this.sendEndTime = sendEndTime;
    }

    public String getCouponAvailablePeriodType() {
        return couponAvailablePeriodType;
    }

    public void setCouponAvailablePeriodType(String couponAvailablePeriodType) {
        this.couponAvailablePeriodType = couponAvailablePeriodType;
    }

    public String getCouponAbsolutelyBeginTime() {
        return couponAbsolutelyBeginTime;
    }

    public void setCouponAbsolutelyBeginTime(String couponAbsolutelyBeginTime) {
        this.couponAbsolutelyBeginTime = couponAbsolutelyBeginTime;
    }

    public String getCouponAbsolutelyEndTime() {
        return couponAbsolutelyEndTime;
    }

    public void setCouponAbsolutelyEndTime(String couponAbsolutelyEndTime) {
        this.couponAbsolutelyEndTime = couponAbsolutelyEndTime;
    }

    public String getCouponRelativeEndRoundingType() {
        return couponRelativeEndRoundingType;
    }

    public void setCouponRelativeEndRoundingType(String couponRelativeEndRoundingType) {
        this.couponRelativeEndRoundingType = couponRelativeEndRoundingType;
    }

    public String getCouponRelativeEndValue() {
        return couponRelativeEndValue;
    }

    public void setCouponRelativeEndValue(String couponRelativeEndValue) {
        this.couponRelativeEndValue = couponRelativeEndValue;
    }
}

==> paycenter-client-3.5.35-20250915.094345-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/alipay/AlipayActivityInfoResponse.java <==
package cn.com.duiba.paycenter.dto.payment.charge.alipay;

import java.io.Serializable;

public class AlipayActivityInfoResponse implements Serializable {

    private static final long serialVersionUID = -4350183925162469662L;

    private String activityId;
    private String activityName;
    private String activityStatus;
    private String sendCount;
    private String userInstructionList;
    private String sendBeginTime;
    private String sendEndTime;
    private String discountThresholdAmt;
    private String discountValue;
    /**
     * 时间周期类型
     * ABSOLUTELY:绝对时间
     * RELATIVE:相对时间
     */
    private String couponAvailablePeriodType;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为ABSOLUTELY时，此处会有值
     * 绝对时间情况下，红包发放开始时间
     * yyyy-MM-dd HH:mm:ss
     */
    private String couponAbsolutelyBeginTime;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为ABSOLUTELY时，此处会有值
     * 绝对时间下红包发放结束时间
     */
    private String couponAbsolutelyEndTime;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为RELATIVE时，此处会有值
     *  相对时间情况下，红包发放开始时间周期类型
     *      DAYS:天级
     *      MINUTES:分钟级
     */
    private String couponRelativeBeginRoundingType;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为RELATIVE时，此处会有值
     * 相对时间情况下，红包开始时间相对值，
     *      比如:
     *      coupon_relative_begin_rounding_type=MINUTES
     *      coupon_relative_begin_value=100
     *      代表从生效时间开始，有效期持续为100分钟
     */
    private String couponRelativeBeginValue;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为RELATIVE时，此处会有值
     *
     * 相对时间情况下，红包发放结束时间周期类型
     * DAYS:天级
     * MINUTES:分钟级
     */
    private String couponRelativeEndRoundingType;
    /**
     * 说明:当coupon_available_period_type不为空的时候且为RELATIVE时，此处会有值
     * 相对时间情况下，红包开始时间相对值，
     *      比如:
     *      coupon_relative_end_rounding_type=MINUTES
     *      coupon_relative_end_value=100
     *      代表从生效时间开始，有效期持续为100分钟
     */
    private String couponRelativeEndValue;
    private Integer bankCardType;
    private String cardBinList;

    public Integer getBankCardType() {
        return bankCardType;
    }

    public void setBankCardType(Integer bankCardType) {
        this.bankCardType = bankCardType;
    }

    public String getCardBinList() {
        return cardBinList;
    }

    public void setCardBinList(String cardBinList) {
        this.cardBinList = cardBinList;
    }

    public String getDiscountThresholdAmt() {
        return discountThresholdAmt;
    }

    public void setDiscountThresholdAmt(String discountThresholdAmt) {
        this.discountThresholdAmt = discountThresholdAmt;
    }

    public String getDiscountValue() {
        return discountValue;
    }

    public void setDiscountValue(String discountValue) {
        this.discountValue = discountValue;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityStatus() {
        return activityStatus;
    }

    public void setActivityStatus(String activityStatus) {
        this.activityStatus = activityStatus;
    }

    public String getSendCount() {
        return sendCount;
    }

    public void setSendCount(String sendCount) {
        this.sendCount = sendCount;
    }

    public String getUserInstructionList() {
        return userInstructionList;
    }

    public void setUserInstructionList(String userInstructionList) {
        this.userInstructionList = userInstructionList;
    }

    public String getSendBeginTime() {
        return sendBeginTime;
    }

    public void setSendBeginTime(String sendBeginTime) {
        this.sendBeginTime = sendBeginTime;
    }

    public String getSendEndTime() {
        return sendEndTime;
    }

    public void setSendEndTime(String sendEndTime) {
        this.sendEndTime = sendEndTime;
    }

    public String getCouponAvailablePeriodType() {
        return couponAvailablePeriodType;
    }

    public void setCouponAvailablePeriodType(String couponAvailablePeriodType) {
        this.couponAvailablePeriodType = couponAvailablePeriodType;
    }

    public String getCouponAbsolutelyBeginTime() {
        return couponAbsolutelyBeginTime;
    }

    public void setCouponAbsolutelyBeginTime(String couponAbsolutelyBeginTime) {
        this.couponAbsolutelyBeginTime = couponAbsolutelyBeginTime;
    }

    public String getCouponAbsolutelyEndTime() {
        return couponAbsolutelyEndTime;
    }

    public void setCouponAbsolutelyEndTime(String couponAbsolutelyEndTime) {
        this.couponAbsolutelyEndTime = couponAbsolutelyEndTime;
    }

    public String getCouponRelativeEndRoundingType() {
        return couponRelativeEndRoundingType;
    }

    public void setCouponRelativeEndRoundingType(String couponRelativeEndRoundingType) {
        this.couponRelativeEndRoundingType = couponRelativeEndRoundingType;
    }

    public String getCouponRelativeEndValue() {
        return couponRelativeEndValue;
    }

    public void setCouponRelativeEndValue(String couponRelativeEndValue) {
        this.couponRelativeEndValue = couponRelativeEndValue;
    }

    public String getCouponRelativeBeginRoundingType() {
        return couponRelativeBeginRoundingType;
    }

    public void setCouponRelativeBeginRoundingType(String couponRelativeBeginRoundingType) {
        this.couponRelativeBeginRoundingType = couponRelativeBeginRoundingType;
    }

    public String getCouponRelativeBeginValue() {
        return couponRelativeBeginValue;
    }

    public void setCouponRelativeBeginValue(String couponRelativeBeginValue) {
        this.couponRelativeBeginValue = couponRelativeBeginValue;
    }
}
